@@ -24,7 +24,6 @@
 
 #include "codeine.h"
 #include "timeLabel.h"
-#include "audioView.h"
 #include "loadView.h"
 
 #include <QList>
@@ -44,6 +43,9 @@ class QMenu;
 class QSlider;
 class QCheckBox;
 
+class AudioView2;
+#include "audioView2.h"
+
 namespace Dragon
 {
    class PlayDialog;
@@ -58,7 +60,7 @@ namespace Dragon
 
       static MainWindow *s_instance;
 
-      friend int ::main( int, char** );
+      friend class PlayerApplication;
       friend QWidget* mainWindow();
 
    public:
@@ -78,8 +80,7 @@ namespace Dragon
       void toggleVolumeSlider( bool );
       void restoreDefaultVideoSettings();
       void toggleLoadView();
-
-
+      void parseArgs();
 
    private slots:
       void setFullScreen( bool full );
@@ -97,6 +98,7 @@ namespace Dragon
       void engineSeekableChanged( bool );
       void engineMetaDataChanged();
       void engineHasVideoChanged( bool );
+      void toggleUnique( bool );
 
    private:
       bool load( const KUrl& );
@@ -118,7 +120,7 @@ namespace Dragon
 //      virtual void readProperties( KConfig* );
 
       QStackedWidget *m_mainView;
-      AudioView *m_audioView;
+      AudioView2 *m_audioView;
       LoadView *m_loadView;
       QWidget *m_currentWidget;
 
